<!-- docs/_sidebar.md -->

# [Installation + Tech Notes](/)

  - [Installation](/)

# [Usage](/how-to)

  - [How To](/how-to)
    
      - [Getting Started](/getting-started)
      - [Loading Data](/loading-data)
      - [Basic Data Exploration](/basic-data-exploration)
          - [Intermediate Data Manipulation](/data-manipulation)
          - [Custom `.S` Functionality](/dot-S-functionality)
          - [Custom `.T` Functionality](/dot-T-functionality)
      - [Curve Fitting](/curve-fitting)
      - [K-space Conversion](/k-space-conversion)
      - [Fermi Edge Corrections](/fermi-edge-corrections)
      - [Interactive Analysis Tools](/interactive)
      - [Statistics](/statistics)
      - [Advanced Plotting](/advanced-plotting)
          - [Stack Plots](/stack-plots)
          - [Brillouin Zones](/brillouin-zones)
          - [Fermi Surfaces](/fermi-surfaces)
          - [3D Cut Plots](/3d-cut-plots)
          - [Spin-ARPES Plots](/spin-arpes)
          - [Ultrafast-ARPES Plots](/tr-arpes)
          - [Annotations](/annotations)
          - [Labeling + Utilities](/plotting-utilities)
      - [Adding a Beamline/Lab Source](/writing-plugins)
      - [Contributing](/contributing)
      - [Customization and Notes on Juypyter](/customization)

  - [Topics](/how-to)
    
      - [Condensed Matter Physics Software Stack](/cmp-stack)
      - [Analysis Spreadsheets](/spreadsheets)
      - [Spectra + Data Representation](/spectra)
      - [Plugins](/writing-plugins)
      - [Data Provenance](/data-provenance)
      - [Phenomenological and Detector Models](/modeling)

# arpes

  -   - [arpes package](arpes)
        
          -   - [Subpackages](arpes#subpackages)
                
                  - [arpes.analysis package](arpes.analysis)
                  - [arpes.corrections package](arpes.corrections)
                  - [arpes.endstations package](arpes.endstations)
                  - [arpes.fits package](arpes.fits)
                  - [arpes.laue package](arpes.laue)
                  - [arpes.models package](arpes.models)
                  - [arpes.plotting package](arpes.plotting)
                  - [arpes.preparation package](arpes.preparation)
                  - [arpes.utilities package](arpes.utilities)
        
          -   - [Submodules](arpes#submodules)
                
                  - [arpes.bootstrap module](arpes.bootstrap)
                  - [arpes.config module](arpes.config)
                  - [arpes.constants module](arpes.constants)
                  - [arpes.exceptions module](arpes.exceptions)
                  - [arpes.experiment module](arpes.experiment)
                  - [arpes.io module](arpes.io)
                  - [arpes.laser module](arpes.laser)
                  - [arpes.load\_pxt module](arpes.load_pxt)
                  - [arpes.optics module](arpes.optics)
                  - [arpes.pipeline module](arpes.pipeline)
                  - [arpes.pipelines module](arpes.pipelines)
                  - [arpes.provenance module](arpes.provenance)
                  - [arpes.repair module](arpes.repair)
                  - [arpes.simulation module](arpes.simulation)
                  - [arpes.typing module](arpes.typing)
                  - [arpes.widgets module](arpes.widgets)
                  - [arpes.xarray\_extensions
                    module](arpes.xarray_extensions)
                  - [arpes.xarray\_html\_repr
                    module](arpes.xarray_html_repr)
        
          - [Module contents](arpes#module-arpes)
